
% Solves the ``susceptible block'' and backs-out the remaining value functions


% Iteration variables
diff = 100;
iter = 0;

% INITIALISE THE SURPLUS FUNCTION
if aux.steady_state==0 && iter_outer==1 && aux.lockdown==0
    S_s0 = repmat(ss.S_s, 1, state_length); 
    S_s1 = repmat(ss.S_s, 1, state_length); 
    
elseif aux.steady_state==0 && iter_outer==1 && aux.lockdown==1 && aux.furlough==0
    S_s0_L = repmat(ss_ld.S_s_L,1, state_length);
    S_s0_U = repmat(ss_ld.S_s_U,1, state_length);
    S_s1_L = repmat(ss_ld.S_s_L,1, state_length);
    S_s1_U = repmat(ss_ld.S_s_U,1, state_length);
    
elseif aux.steady_state==0 && iter_outer==1 && aux.lockdown==1 && aux.furlough==1
    S_s0_L = repmat(ss_ld.S_s_L,1, state_length);
    S_s0_U = repmat(ss_ld.S_s_U,1, state_length);
    
    S_s1_L = repmat(ss_ld.S_s_L,1, state_length);
    S_s1_U = repmat(ss_ld.S_s_U,1, state_length);

    S_s2_L = repmat(ss_ld.S_s_L,1, state_length);
    S_s2_U = repmat(ss_ld.S_s_U,1, state_length);
   
end

if aux.lockdown==1 && aux.steady_state==0
    S_s0 = laissez.S_s0;   
    S_s1 = laissez.S_s1;   
    S_r = laissez.S_r;      
    S_i = laissez.S_i;
end


%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
% REMAINING VALUE FUNCTIONS (of infected)
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

U_i = ( param.rho_y*U_r + gamma_y_min + param.eta*R_i ) ./ ...
           (param.r + param.rho_y    + gamma_y_min         + param.eta);   

if aux.lockdown==1      
     U_i_L = ( param.rho_y*U_r_L + gamma_y_min + param.eta*R_i_L + param.Lambda*U_i)./ ...
         (param.r + param.rho_y + gamma_y_min + param.eta  + param.Lambda);    
end 

%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
% SURPLUS FIXED POINT ITERATIONS
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
while diff>aux.conv_diff
    
    if aux.lockdown==0
        max_Ss0Ss1 = max(S_s0,S_s1);
        max_Ss0Ss1 = max(max_Ss0Ss1,0);


        U_s = ( param.b_u + param.beta*phi.*(f'*max_Ss0Ss1)  + param.lambda_0y*li.*U_i + param.eta*R_s ) ./ ...
            (param.r + param.lambda_0y.*li + param.eta);
    
        
        S_s0_new = ( ...
                repmat(p0 - param.b_u,1,state_length) - ...
                param.beta*repmat(phi.*(f'*max_Ss0Ss1),aux.x_grid*aux.alpha_grid,1 )...
                + param.lambda_0y*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i + ...
                param.nu*max_Ss0Ss1 ) ./ ...
                (param.r + param.delta + param.eta + param.nu + param.lambda_0y*repmat(li,aux.x_grid*aux.alpha_grid,1) );

        S_s1_new = ( ...
                repmat(p1 - param.b_u,1,state_length) - ...
                param.beta*repmat(phi.*(f'*max_Ss0Ss1),aux.x_grid*aux.alpha_grid,1 ) ...
                + (param.lambda_0y + param.lambda_1y)*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i  ...
                + param.lambda_1y*repmat(li.*(U_i - U_s),aux.x_grid*aux.alpha_grid,1) + param.nu*max_Ss0Ss1 ) ./ ...
                (param.r + param.delta + param.eta + param.nu + (param.lambda_0y + param.lambda_1y)*repmat(li,aux.x_grid*aux.alpha_grid,1) );
        
        
        diff0 = max(abs( reshape(S_s0_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s0,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s0,aux.x_grid*aux.alpha_grid*state_length,1)) );

        diff1 = max(abs( reshape(S_s1_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s1,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s1,aux.x_grid*aux.alpha_grid*state_length,1)) );
        
        
        diff = max(diff0,diff1)

        S_s0 = 0.5*S_s0_new+S_s0*0.5;
        S_s1 = 0.5*S_s1_new+S_s1*0.5;
        
    elseif aux.lockdown==1 && aux.furlough==0
        
        max_Ss0Ss1_L = max(S_s0_L,S_s1_L);
        max_Ss0Ss1_L = max(max_Ss0Ss1_L,0);
        
        max_Ss0Ss1_U = max(S_s0_U,S_s1_U);
        max_Ss0Ss1_U = max(max_Ss0Ss1_U,0);
     
        S_s0_L_new = ( ...
            repmat(p0 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi.*(f'*max_Ss0Ss1_L),aux.x_grid*aux.alpha_grid,1 )  ...
            - (1-param.pi)*param.beta*repmat(phi.*(f'*max_Ss0Ss1_U),aux.x_grid*aux.alpha_grid,1 )  ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_L + ...
            param.nu*max_Ss0Ss1_L + param.Lambda*S_s0) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);

         S_s0_U_new = ( ...
            repmat(p0 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi.*(f'*max_Ss0Ss1_L),aux.x_grid*aux.alpha_grid,1 )  ...
            - (1-param.pi)*param.beta*repmat(phi.*(f'*max_Ss0Ss1_U),aux.x_grid*aux.alpha_grid,1 )  ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_U + ...
            param.nu*max_Ss0Ss1_U + param.Lambda*S_s0) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);

       S_s1_L_new = ( ...
            repmat(p0 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi.*(f'*max_Ss0Ss1_L),aux.x_grid*aux.alpha_grid,1 )  ...
            -(1-param.pi)*param.beta*repmat(phi.*(f'*max_Ss0Ss1_U),aux.x_grid*aux.alpha_grid,1 )  ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_L + ...
            param.nu*max_Ss0Ss1_L + param.Lambda*S_s1) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);

       U_s_L = (param.b_u + param.pi*param.beta*(phi.*(f'*max_Ss0Ss1_L) )  ...
            + (1-param.pi)*param.beta*(phi.*(f'*max_Ss0Ss1_U) ) ...
            + param.lambda_0y_ld*li.*U_i_L + param.eta*R_s_L + param.Lambda*U_s)./ ...
            (param.r + param.lambda_0y_ld*li + param.eta + param.Lambda);

       S_s1_U_new = ( ...
            repmat(p1 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi.*(f'*max_Ss0Ss1_L),aux.x_grid*aux.alpha_grid,1 )  ...
            - (1-param.pi)*param.beta*repmat(phi.*(f'*max_Ss0Ss1_U),aux.x_grid*aux.alpha_grid,1 )  ...
            + (param.lambda_0y_ld + param.lambda_1y)*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_U + ...
            param.lambda_1y*repmat(li,aux.x_grid*aux.alpha_grid,1).*repmat(U_i_L - U_s_L,aux.x_grid*aux.alpha_grid,1) + ...
            param.nu*max_Ss0Ss1_U + param.Lambda*S_s1) ./ ...
            (param.r + param.delta + param.eta + param.nu + (param.lambda_0y_ld + param.lambda_1y)*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);

        diff0_L = max(abs( reshape(S_s0_L_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s0_L,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s0_L,aux.x_grid*aux.alpha_grid*state_length,1)) );

        diff1_L = max(abs( reshape(S_s1_L_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s1_L,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s1_L,aux.x_grid*aux.alpha_grid*state_length,1)) );
        
        diff0_U = max(abs( reshape(S_s0_U_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s0_U,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s0_U,aux.x_grid*aux.alpha_grid*state_length,1)) );

        diff1_U = max(abs( reshape(S_s1_U_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s1_U,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s1_U,aux.x_grid*aux.alpha_grid*state_length,1)) );
        
        diff = max([diff0_L,diff1_L,diff0_U,diff1_U]);
        [diff0_L,diff1_L,diff0_U,diff1_U]
        if iter<100
            S_s0_L = S_s0_L_new;
            S_s1_L = S_s1_L_new;
            S_s0_U = S_s0_U_new;
            S_s1_U = S_s1_U_new;
        else
            S_s0_L = 0.9*S_s0_L + 0.1*S_s0_L_new;
            S_s1_L = 0.9*S_s1_L + 0.1*S_s1_L_new;
            S_s0_U = 0.9*S_s0_U + 0.1*S_s0_U_new;
            S_s1_U = 0.9*S_s1_U + 0.1*S_s1_U_new;
            iter
        end
        
        
     elseif aux.lockdown==1 && aux.furlough==1
        
        max_Ss0Ss1_L = max(S_s0_L,S_s1_L);
        max_Ss0Ss1_L = max(max_Ss0Ss1_L,0);
        
        max_Ss0Ss1_U = max(S_s0_U,S_s1_U);
        max_Ss0Ss1_U = max(max_Ss0Ss1_U,0);
        
       
        S_s0_L_new = ( ...
            repmat(p0 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_L.*repmat(f,1,state_length)) ...
            - (1-param.pi)*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_U.*repmat(f,1,state_length)) ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_L + ...
            param.nu*max(S_s2_L,max_Ss0Ss1_L) + param.Lambda*S_s0) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);
        
       S_s1_L_new = ( ...
            repmat(p0 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_L.*repmat(f,1,state_length)) ...
            - (1-param.pi)*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_U.*repmat(f,1,state_length)) ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_L + ...
            param.nu*max(S_s2_L,max_Ss0Ss1_L) + param.Lambda*S_s1) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);
      
        
      S_s2_L_new = ( ...
            repmat(p2 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_L.*repmat(f,1,state_length)) ...
            - (1-param.pi)*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_U.*repmat(f,1,state_length)) ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_L + ...
            param.nu*max(S_s2_L,max_Ss0Ss1_L) + param.Lambda*max(S_s0,S_s1)) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);
      
       
     S_s0_U_new = ( ...
            repmat(p0 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_L.*repmat(f,1,state_length)) ...
            - (1-param.pi)*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_U.*repmat(f,1,state_length)) ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_U + ...
            param.nu*max(S_s2_U,max_Ss0Ss1_U) + param.Lambda*S_s0) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);

     U_s_L = (param.b_u + param.pi*param.beta*phi.*sum(max_Ss0Ss1_L.*repmat(f,1,state_length)) ...
            + (1-param.pi)*param.beta*phi.*sum(max_Ss0Ss1_U.*repmat(f,1,state_length)) ...
            + param.lambda_0y_ld*li.*U_i_L + param.eta*R_s_L + param.Lambda*U_s)./ ...
            (param.r + param.lambda_0y_ld*li + param.eta + param.Lambda);
        
     S_s1_U_new = ( ...
            repmat(p1 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_L.*repmat(f,1,state_length)) ...
            - (1-param.pi)*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_U.*repmat(f,1,state_length)) ...
            + (param.lambda_0y_ld + param.lambda_1y)*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_U + ...
            param.lambda_1y*repmat(li,aux.x_grid*aux.alpha_grid,1).*(U_i_L - U_s_L) + ...
            param.nu*max(S_s2_U,max_Ss0Ss1_U) + param.Lambda*S_s1) ./ ...
            (param.r + param.delta + param.eta + param.nu + (param.lambda_0y_ld + param.lambda_1y)*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);
     
        
     S_s2_U_new = ( ...
            repmat(p2 - param.b_u,1,state_length) ...
            - param.pi*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_L.*repmat(f,1,state_length)) ...
            - (1-param.pi)*param.beta*repmat(phi,aux.x_grid*aux.alpha_grid,1).*sum(max_Ss0Ss1_U.*repmat(f,1,state_length)) ...
            + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1).*S_i_U + ...
            param.nu*max(S_s2_U,max_Ss0Ss1_U) + param.Lambda*max(S_s1,S_s0)) ./ ...
            (param.r + param.delta + param.eta + param.nu + param.lambda_0y_ld*repmat(li,aux.x_grid*aux.alpha_grid,1) + param.Lambda);
        
        
      diff0_L = max(abs( reshape(S_s0_L_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s0_L,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s0_L,aux.x_grid*aux.alpha_grid*state_length,1)) );

      diff1_L = max(abs( reshape(S_s1_L_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s1_L,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s1_L,aux.x_grid*aux.alpha_grid*state_length,1)) );
        
      diff2_L = max(abs( reshape(S_s2_L_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s2_L,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s2_L,aux.x_grid*aux.alpha_grid*state_length,1)) );
        
      diff0_U = max(abs( reshape(S_s0_U_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s0_U,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s0_U,aux.x_grid*aux.alpha_grid*state_length,1)) );

      diff1_U = max(abs( reshape(S_s1_U_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s1_U,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s1_U,aux.x_grid*aux.alpha_grid*state_length,1)) );
        
      diff2_U = max(abs( reshape(S_s2_U_new,aux.x_grid*aux.alpha_grid*state_length,1) - ...
            reshape(S_s2_U,aux.x_grid*aux.alpha_grid*state_length,1) ) ./ ...
            abs(reshape(S_s2_U,aux.x_grid*aux.alpha_grid*state_length,1)) );
        
      diff = max([diff0_L,diff1_L,diff2_L,diff0_U,diff1_U,diff2_U]);
        [diff0_L,diff1_L,diff2_L,diff0_U,diff1_U,diff2_U]
        if diff>0.05 
            S_s0_L = S_s0_L_new;
            S_s1_L = S_s1_L_new;
            S_s2_L = S_s2_L_new;
            S_s0_U = S_s0_U_new;
            S_s1_U = S_s1_U_new;
            S_s2_U = S_s2_U_new;
        else
            S_s0_L = 0.9*S_s0_L + 0.1*S_s0_L_new;
            S_s1_L = 0.9*S_s1_L + 0.1*S_s1_L_new;
            S_s2_L = 0.9*S_s2_L + 0.1*S_s2_L_new;
            S_s0_U = 0.9*S_s0_U + 0.1*S_s0_U_new;
            S_s1_U = 0.9*S_s1_U + 0.1*S_s1_U_new;
            S_s2_U = 0.9*S_s2_U + 0.1*S_s2_U_new;
            iter
        end
        
        
    end
    iter=iter+1;
end




if aux.lockdown==0
    S_s = max(S_s0,S_s1);
else
    S_s_L = max(S_s0_L, S_s1_L);
    S_s_U = max(S_s0_U, S_s1_U);
end
    
    
    

