function output = full_model(theta, MOM, param, aux)
    
    if aux.t_period <aux.T %if lockdown not implemented or implemeted after time window not neccesary
        param.Lambda = theta(1); %length of lockdown
    end
    
    param.lambda_0y_ld = param.lambda_0y*(1-param.alpha*param.pi); 
    param.lambda_o_ld  = param.lambda_o*(1-param.alpha*param.pi);
    
    
    %%
    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %solve the model (in steady_state) 
    tic
    model_solve;
    toc
    e = states(1)*phi*(S_s>=0).*f./(param.delta+param.eta);

    ss = struct( ...
        'u_s', states(1),...
        'e_s', e*states(2)/sum(e), ...
        'o_s', states(3), ...
        'S_s', S_s,...
        'S_r', S_r, ...
        'phi', phi, ...
        'phi_f',phi_f, ...
        'tight',tight_new ...
        );
    clear e
    SR_3_I;
    ss.S_i = S_i;

    %% LOCKDOWN
    if aux.t_period <aux.T
    
        % solve lockdown model in steady stae
        aux.lockdown=1;

        tic
        model_solve
        toc

        ss_ld = struct( ...
            'u_s', states(1),...
            'S_r_U', S_r_U, ...
            'S_r_L', S_r_L, ...
            'S_s_L', S_s_L,...
            'S_s_U', S_s_U,...        
            'phi', phi, ...
            'phi_f',phi_f, ...
            'tight',tight_new ...
            );

        if aux.furlough==1
            ss_ld.S_r_U_2 = S_r_U_2;
            ss_ld.S_r_L_2 = S_r_L_2;
            ss_ld.S_s2_L = S_s2_L;
        end


        SR_3_I;
        ss_ld.S_i_L=S_i_L;
        ss_ld.S_i_U=S_i_U;

    end
    
   
    
    
    %%
    %%%%%%%%%%%%%%%%%%%%%%%%%
    %solve big model out of steady_state
    aux.steady_state=0;
    aux.lockdown=0;
    aux.update=1;
    aux.display=1;
    tic
    model_solve
    toc

    laissez = struct('S_i',S_i,...
        'S_r', S_r, ...
        'S_s1',S_s1, ...
        'S_s0',S_s0,...
        'phi',phi);

    %% LOCKDOWN
    
    if aux.t_period <aux.T
        
    % solve lockdown model out of steady stae
    aux.lockdown=1;

    %%%%%%%%%%%%%%%%%%%%%%%%%
    %solve big model in lockdown out of steady_state
    aux.steady_state=0;
    tic
    model_solve
    toc

    locked = struct( ...
        'S_s0_L', S_s0_L , ...
        'S_s1_L', S_s1_L , ...
        'S_s0_U', S_s0_U , ...
        'S_s1_U', S_s1_U , ...
        'S_s_L', S_s_L,...
        'S_i_L', S_i_L,...
        'S_r_L', S_r_L, ...
        'S_s_U', S_s_U,...
        'S_i_U', S_i_U, ...
        'S_r_U', S_r_U, ...
        'phi', phi, ...
        'phi_f',phi_f ...
        );

    if aux.furlough==1
        locked.S_r_U_2 = S_r_U_2;
        locked.S_r_L_2 = S_r_L_2;
        locked.S_s2_U  = S_s2_U;
        locked.S_s2_L  = S_s2_L;
    end
    
    end
           
    %%

    %%%%%%%%%%%%%%%%%%%%%%%
    % Solve for dynamics
    %%%%%%%%%%%%%%%%%%%%%%%

    state_space = [ [u_s;u_r;li] , [ss.u_s;0;0],[0;ss.u_s;0]  ];

    % economy not in lockdown
    Si = [laissez.S_i, ss.S_i, ss.S_i];
    Sr = [laissez.S_r, ss.S_r, ss.S_r];
    Ss1 = [laissez.S_s1, ss.S_s, ss.S_s];
    Ss0 = [laissez.S_s0, -2*max(abs(S_s1),[],2), -2*max(abs(S_s1),[],2)]; 
    Ss = max(Ss1,Ss0);
    phi = [laissez.phi, ss.phi, ss.phi];

    %economy in lockdown
    if aux.t_period <aux.T
        phi_ld  = [locked.phi, ss_ld.phi, ss_ld.phi];

        Si_L_ld = [locked.S_i_L, ss_ld.S_i_L, ss_ld.S_i_L];
    
        Sr_L_ld = [locked.S_r_L, ss_ld.S_r_L, ss_ld.S_r_L];
    
        Ss1_L_ld = [locked.S_s1_L, ss_ld.S_s_L, ss_ld.S_s_L];
        Ss0_L_ld = [locked.S_s0_L, -2*max(abs(S_s1_L),[],2), -2*max(abs(S_s1_L),[],2)]; 
        Ss_L_ld  = max(Ss1_L_ld,Ss0_L_ld);

        Si_U_ld = [locked.S_i_U, ss_ld.S_i_U, ss_ld.S_i_U];
    
        Sr_U_ld = [locked.S_r_U, ss_ld.S_r_U, ss_ld.S_r_U];
    
        Ss1_U_ld = [locked.S_s1_U, ss_ld.S_s_U, ss_ld.S_s_U];
        Ss0_U_ld = [locked.S_s0_U, -2*max(abs(S_s1_U),[],2), -2*max(abs(S_s1_U),[],2)]; 
        Ss_U_ld  = max(Ss1_U_ld,Ss0_U_ld);
    
        if aux.furlough==1
            Sr2_U_ld = [locked.S_r_U_2, ss_ld.S_r_U_2, ss_ld.S_r_U_2 ];
            Sr2_L_ld = [locked.S_r_L_2, ss_ld.S_r_L_2, ss_ld.S_r_L_2 ];
            Ss2_L_ld = [locked.S_s2_L, ss_ld.S_s2_L, ss_ld.S_s2_L    ];
            Ss2_U_ld = [locked.S_s2_U,  -2*max(abs(S_s1_L),[],2), -2*max(abs(S_s1_L),[],2) ]; 
        end

    end
    
    wages; 
    
    if aux.furlough==0
        
        dynamics;

        output = struct( ...
            'us_t',us(init+1:360*5), ...
            'ui_t',ui(init+1:360*5), ...
            'ur_t',ur(init+1:360*5), ...
            'es0_L_ld_t',es0_L_ld(:,init+1:360*5), ...
            'es1_L_ld_t',es1_L_ld(:,init+1:360*5), ...
            'es0_t',es0(:,init+1:360*5), ...
            'es1_t',es1(:,init+1:360*5), ...
            'ei_L_ld_t',ei_L_ld(:,init+1:360*5), ...
            'ei_t',ei(:,init+1:360*5),...
            'er_L_ld_t',er_L_ld(:,init+1:360*5), ...
            'er_t',er(:,init+1:360*5), ...
            'os_t',os_t(init+1:360*5), ...
            'oi_t',oi_t(init+1:360*5), ...
            'or_t',or_t(init+1:360*5), ...
            'ws0',ws0(:,init+1:360*5), ...
            'ws1',ws1(:,init+1:360*5), ...
            'wi',wi(:,init+1:360*5), ...
            'wr',wr(:,init+1:360*5), ...
            'ws0_L_ld',ws0_L_ld(:,init+1:360*5), ...
            'ws1_L_ld',ws1_L_ld(:,init+1:360*5), ...
            'wi_L_ld',wi_L_ld(:,init+1:360*5), ...
            'wr_L_ld',wr_L_ld(:,init+1:360*5), ...
            ...'ws0_sq',ws0_sq(:,init+1:360*5), ...
            ...'ws1_sq',ws1_sq(:,init+1:360*5), ...
            ...'wi_sq',wi_sq(:,init+1:360*5), ...
            ...'wr_sq',wr_sq(:,init+1:360*5), ...
            ...'ws0_sq_L_ld',ws0_sq_L_ld(:,init+1:360*5), ...
            ...'ws1_sq_L_ld',ws1_sq_L_ld(:,init+1:360*5), ...
            ...'wi_sq_L_ld',wi_sq_L_ld(:,init+1:360*5), ...
            ...'wr_sq_L_ld',wr_sq_L_ld(:,init+1:360*5), ...
            'deaths',deaths(init+1:360*5),...
            'jfr',jfr(init+1:360*5),...
            'jsep',jsep(init+1:360*5),...
            'locked',locked(init+1:360*5),...
            'outp', outp(init+1:360*5) ,...
            'emp_t',emp(:,init+1:360*5), ...
            'unemp_t',unemp(:,init+1:360*5), ...
            'pop', pop(init+1:360*5) ,...
            'mean_wage',mean_wage(init+1:360*5),...
            'mean_wage_noinf',mean_wage_noinf(init+1:360*5),...
            'income', income(init+1:360*5) ...
            );
        
        elseif aux.furlough==1
            
            dynamics_furlough

            output = struct( ...
                'us_t',us(init+1:360*5), ...
                'ui_t',ui(init+1:360*5), ...
                'ur_t',ur(init+1:360*5), ...
                'es0_L_ld_t',es0_L_ld(:,init+1:360*5), ...
                'es1_L_ld_t',es1_L_ld(:,init+1:360*5), ...
                'es2_L_ld_t',es2_L_ld(:,init+1:360*5), ...
                'es0_t',es0(:,init+1:360*5), ...
                'es1_t',es1(:,init+1:360*5), ...
                'es2_t',es2(:,init+1:360*5), ...
                'ei_L_ld_t',ei_L_ld(:,init+1:360*5), ...
                'ei_t',ei(:,init+1:360*5),...
                'ei2_L_ld_t',ei2_L_ld(:,init+1:360*5), ...
                'ei2_t',ei2(:,init+1:360*5),...
                'er_L_ld_t',er_L_ld(:,init+1:360*5), ...
                'er_t',er(:,init+1:360*5), ...
                'er2_L_ld_t',er2_L_ld(:,init+1:360*5), ...
                'er2_t',er2(:,init+1:360*5), ...
                'ws0',ws0(:,init+1:360*5), ...
                'ws1',ws1(:,init+1:360*5), ...
                'ws2',ws2(:,init+1:360*5), ...
                'wi',wi(:,init+1:360*5), ...
                'wi2',wi2(:,init+1:360*5), ...
                'wr',wr(:,init+1:360*5), ...
                'wr2',wr2(:,init+1:360*5), ...
                'ws0_L_ld',ws0_L_ld(:,init+1:360*5), ...
                'ws1_L_ld',ws1_L_ld(:,init+1:360*5), ...
                'ws2_L_ld',ws2_L_ld(:,init+1:360*5), ...
                'wi_L_ld',wi_L_ld(:,init+1:360*5), ...
                'wi2_L_ld',wi2_L_ld(:,init+1:360*5), ...
                'wr_L_ld',wr_L_ld(:,init+1:360*5), ...
                'wr2_L_ld',wr2_L_ld(:,init+1:360*5), ...
                ...'ws0_sq',ws0_sq(:,init+1:360*5), ...
                ...'ws1_sq',ws1_sq(:,init+1:360*5), ...
                ...'ws2_sq',ws2_sq(:,init+1:360*5), ...
                ...'wi_sq',wi_sq(:,init+1:360*5), ...
                ...'wi2_sq',wi2_sq(:,init+1:360*5), ...
                ...'wr_sq',wr_sq(:,init+1:360*5), ...
                ...'wr2_sq',wr2_sq(:,init+1:360*5), ...
                ...'ws0_L_ld_sq',ws0_L_ld_sq(:,init+1:360*5), ...
                ...'ws1_L_ld_sq',ws1_L_ld_sq(:,init+1:360*5), ...
                ...'ws2_L_ld_sq',ws2_L_ld_sq(:,init+1:360*5), ...
                ...'wi_L_ld_sq',wi_L_ld_sq(:,init+1:360*5), ...
                ...'wi2_L_ld_sq',wi2_L_ld_sq(:,init+1:360*5), ...
                ...'wr_L_ld_sq',wr_L_ld_sq(:,init+1:360*5), ...
                ...'wr2_L_ld_sq',wr2_L_ld_sq(:,init+1:360*5), ...
                'os_t',os_t(init+1:360*5), ...
                'oi_t',oi_t(init+1:360*5), ...
                'or_t',or_t(init+1:360*5), ...
                'deaths',deaths(init+1:360*5),...
                'jfr',jfr(init+1:360*5),...
                'jsep',jsep(init+1:360*5),...
                'locked',locked(init+1:360*5),...
                'outp', outp(init+1:360*5) ,...
                'pop', pop(init+1:360*5) ,...
                'emp_t',emp(:,init+1:360*5), ...
                'unemp_t',unemp(:,init+1:360*5), ...
                'furl', furl(init+1:360*5),...
                'mean_wage',mean_wage(init+1:360*5),...
                'mean_wage_noinf',mean_wage_noinf(init+1:360*5),...
                'income', income(init+1:360*5) ...
                );
    end
    


    
        
        
end

