fprintf('\nprint figures 5\n')
clear
close all;

aux = struct( ...
    'steady_state', 1,...   % whether or not initiating model at ss with li=0
    'x_grid', 50,...        % size of productivity grid
    'trim', 1e-2, ...       % trimming of distributions
    'x_lb', 0.5, ...        % lower bound of productiviry distribution 
    'alpha_grid', 50,...
    'inf_grid', 120 ,...
    'us_grid', 5, ...
    'ur_grid', 5, ...
    'max_li', 0.25, ...
    'max_us', 0.4, ...
    'max_ur', 0.2,...   
    'display', 0, ...
    'calibrate',0, ...
    'T',365*5, ...          % number of dts simulated for
    'dt',1/7, ...
    'l_ini', 1/66/10^6, ... % initial 'viral load'
    'conv_diff',1e-2, ...   % relative difference required for convergence tolerance
    'update',0.1, ...       % weight of new variable when updating
    'lockdown',0, ...       % whether the model is solved in lockdown
    'death_ini', 1, ...     % start time series when UK hits this number of Covid deaths
    't_period', 24, ...     % number of dts to implement lockdown
    'furlough',0 ...        % indicator if furlough is in place
    );

% Load parameters
load('final_param.mat','param')

% Solve model in SS
model_solve;

% Compute unemp/emp and retired by age
phi_til = phi*(f'*(S_s>=0));
da = 1;
a_length = 1+52*50; %let age run from 25-100
u_a=zeros(a_length,1);
e_a=zeros(a_length,1);
o_a=zeros(a_length,1);
u_a(1)=1- exp(-param.psi*da);

for tt=2:a_length
    u_a(tt) = u_a(tt-1) - (1-exp(-u_a(tt-1)*param.eta*da)) - ...
                          (1-exp(-u_a(tt-1)*phi_til*da))   + (1-exp(-e_a(tt-1)*param.delta*da));
    e_a(tt) = e_a(tt-1) - (1-exp(-e_a(tt-1)*param.eta*da)) + ...
                          (1-exp(-u_a(tt-1)*phi_til*da))   - (1-exp(-e_a(tt-1)*param.delta*da));
    o_a(tt) = o_a(tt-1) + (1-exp(-u_a(tt-1)*param.eta*da)) + ...
                          (1-exp(-e_a(tt-1)*param.eta*da)) - (1-exp(-o_a(tt-1)*param.chi*da));
end

load('final_model_age.mat','lck_3_age','lck_6_age','lf_age')

TT = 365;

deaths_a_lf   = ([u_a,e_a,o_a]./repmat(u_a+e_a+o_a,1,3))*sum(lf_age.deaths(:,1:TT),2);
deaths_a_lck3 = ([u_a,e_a,o_a]./repmat(u_a+e_a+o_a,1,3))*sum(lck_3_age.deaths(:,1:TT),2);
deaths_a_lck6 = ([u_a,e_a,o_a]./repmat(u_a+e_a+o_a,1,3))*sum(lck_6_age.deaths(:,1:TT),2);

figure(1)
subplot(121)
plot(linspace(25,100,a_length),100*deaths_a_lf,'k-','linewidth',3)
hold on
plot(linspace(25,100,a_length),100*deaths_a_lck3,'r-','linewidth',3)
hold on
plot(linspace(25,100,a_length),100*deaths_a_lck6,'b-','linewidth',3)

xlabel('Age at Start of Lockdown')
ylabel('Mortality rate, %')
%set(gca,'fontsize',20)
axis([25.5 80 0 1.5])
title('Probability of Covid-19 death')

emp_lf  = zeros(3,TT);
for ii=1:3
    
    ss = size(lf_age.es0_L_ld_t );
    emp1 = sum(reshape(lf_age.es0_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lf_age.es1_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lf_age.es0_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lf_age.es1_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lf_age.ei_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lf_age.ei_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lf_age.er_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lf_age.er_t(ii,:,:),ss(2),ss(3) ));
       
    no_emp1 = lf_age.us_t(ii,:) + lf_age.ui_t(ii,:) + lf_age.ur_t(ii,:) + ...
              lf_age.os_t(ii,:) + lf_age.oi_t(ii,:) + lf_age.or_t(ii,:);
          
    emp_lf(ii,:) = emp1(1:TT)./( emp1(1:TT) + no_emp1(1:TT) );
end
clear emp1 no_emp1 ss


emp_l3 = zeros(3,TT);
for ii=1:3
    ss = size(lck_3_age.es0_L_ld_t );
    emp1 = sum(reshape(lck_3_age.es0_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_3_age.es1_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_3_age.es0_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_3_age.es1_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_3_age.ei_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_3_age.ei_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_3_age.er_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_3_age.er_t(ii,:,:),ss(2),ss(3) ));
    
    no_emp1 = lck_3_age.us_t(ii,:) + lck_3_age.ui_t(ii,:) + lck_3_age.ur_t(ii,:) + ...
              lck_3_age.os_t(ii,:) + lck_3_age.oi_t(ii,:) + lck_3_age.or_t(ii,:);
          
    emp_l3(ii,:) = emp1(1:TT)./( emp1(1:TT) + no_emp1(1:TT) );
end
clear emp1 no_emp1 ss


emp_l6 = zeros(3,TT);
for ii=1:3
    ss = size(lck_6_age.es0_L_ld_t );
    emp1 = sum(reshape(lck_6_age.es0_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_6_age.es1_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_6_age.es0_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_6_age.es1_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_6_age.ei_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_6_age.ei_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_6_age.er_L_ld_t(ii,:,:),ss(2),ss(3) )) + ...
           sum(reshape(lck_6_age.er_t(ii,:,:),ss(2),ss(3) ));
    
    no_emp1 = lck_6_age.us_t(ii,:) + lck_6_age.ui_t(ii,:) + lck_6_age.ur_t(ii,:) + ...
              lck_6_age.os_t(ii,:) + lck_6_age.oi_t(ii,:) + lck_6_age.or_t(ii,:);
    emp_l6(ii,:) = emp1(1:TT)./( emp1(1:TT) + no_emp1(1:TT) );
end
clear emp1 no_emp1 ss


e_lf  = ([u_a,e_a,o_a]./repmat(u_a+e_a+o_a,1,3))*sum(emp_lf,2) ./length(emp_lf);
e_l3 = ([u_a,e_a,o_a]./repmat(u_a+e_a+o_a,1,3))*sum(emp_l3,2)./length(emp_l3);
e_l6 = ([u_a,e_a,o_a]./repmat(u_a+e_a+o_a,1,3))*sum(emp_l6,2)./length(emp_l6);

%% Figure 5
figure(1)
subplot(122)
plot(linspace(25,100,a_length),e_lf,'k-','linewidth',3)
hold on
plot(linspace(25,100,a_length),e_l3,'r-','linewidth',3)
hold on
plot(linspace(25,100,a_length),e_l6,'b-','linewidth',3)

ylabel('Employment probability')
xlabel('Age at Start of Lockdown') 
%set(gca,'fontsize',20)

legend('Laissez faire', '3 Month Lockdown', '6 Month Lockdown', 'location','Northeast')
axis([25 80 0.45 0.725])
title('Mean proportion of time employed')

saveas(gcf,'BRS_Figure_5.png')
