fprintf('\nprint figures 4 and 7\n')
clear
close all;

%% Employment and Infection risk
% Load 
load('final_model_risk.mat')

% Auxiliaries
aux = struct( ...
    'steady_state', 1,...   % whether or not initiating model at ss with li=0
    'x_grid', 50,...        % size of productivity grid
    'trim', 1e-2, ...       % trimming of distributions
    'x_lb', 0.5, ...        % lower bound of productiviry distribution 
    'alpha_grid', 50,...
    'inf_grid', 120 ,...
    'us_grid', 5, ...
    'ur_grid', 5, ...
    'max_li', 0.25, ...
    'max_us', 0.4, ...
    'max_ur', 0.2,...   
    'display', 0, ...
    'calibrate',0, ...
    'T',365*5, ...          % number of dts simulated for
    'dt',1/7, ...
    'l_ini', 1/66/10^6, ... % initial 'viral load'
    'conv_diff',1e-2, ...   % relative difference required for convergence tolerance
    'update',0.1, ...       % weight of new variable when updating
    'lockdown',0, ...       % whether the model is solved in lockdown
    'death_ini', 1, ...     % start time series when UK hits this number of Covid deaths
    't_period', 24, ...     % number of dts to implement lockdown
    'furlough',0 ...        % indicator if furlough is in place
    );

% load parameters
load('final_param.mat','param')


emp_dec_lf = zeros(2,9);
infect_dec_lf = zeros(2,9);
emp_dec_lck3 = zeros(2,9);
infect_dec_lck3 = zeros(2,9);
emp_dec_lck6 = zeros(2,9);
infect_dec_lck6 = zeros(2,9);

for i = 1:2
    
    if (i == 1)
        aux.furlough = 0;
    else
        aux.furlough = 1;
    end
    
    
    for pp=1:3

        if pp==1
            tmp = lf_risk;
        elseif pp==2
            if aux.furlough == 0
                tmp = lck_3_risk;
            else
                tmp = lck_f_3_risk;
            end
        elseif pp==3
            if aux.furlough == 0
                tmp = lck_6_risk;
            else
                tmp = lck_f_6_risk;
            end
        end

       emp_dec=zeros(9,1);
        for dec=1:9
            if  (aux.furlough == 1 && pp == 1) || (aux.furlough == 0)

                emp_dec(dec) = sum(tmp.es1_L_ld_t(dec,:,end))+sum(tmp.es0_L_ld_t(dec,:,end))+sum(tmp.es1_t(dec,:,end)) ...
                    + sum(tmp.es0_t(dec,:,end))+ sum(tmp.ei_L_ld_t(dec,:,end))+sum(tmp.ei_t(dec,:,end))...
                    +sum(tmp.er_t(dec,:,end))+sum(tmp.er_L_ld_t(dec,:,end));

            elseif (aux.furlough == 1 && pp > 1)

                emp_dec(dec) = sum(tmp.es1_L_ld_t(dec,:,end))+sum(tmp.es0_L_ld_t(dec,:,end))+sum(tmp.es1_t(dec,:,end)) ...
                    + sum(tmp.es0_t(dec,:,end))+ sum(tmp.ei_L_ld_t(dec,:,end))+sum(tmp.ei_t(dec,:,end))...
                    +sum(tmp.er_t(dec,:,end))+sum(tmp.er_L_ld_t(dec,:,end)) ...
                    +sum(tmp.es2_L_ld_t(dec,:,end)) + sum(tmp.es2_t(dec,:,end)) ...
                    +sum(tmp.ei2_L_ld_t(dec,:,end)) + sum(tmp.ei2_t(dec,:,end)) ...
                    +sum(tmp.er2_L_ld_t(dec,:,end)) + sum(tmp.er2_t(dec,:,end));

            end
        end

        infect_dec=zeros(9,1);
        for dec=1:9

          if  (aux.furlough == 1 && pp == 1) || (aux.furlough == 0)

            infect_dec(dec) = sum(tmp.ei_L_ld_t(dec,:,end))+sum(tmp.ei_t(dec,:,end))...
                +sum(tmp.er_t(dec,:,end))+sum(tmp.er_L_ld_t(dec,:,end)) + ... 
                + tmp.ui_t(dec,end) + tmp.ur_t(dec,end) + tmp.oi_t(dec,end) + tmp.or_t(dec,end) + ...
                + sum(tmp.deaths(:,end)) + ...
                + sum( 1 - exp(-tmp.oi_t(:,end)*param.chi*aux.dt) );

          elseif (aux.furlough == 1 && pp > 1)

            infect_dec(dec) = sum(tmp.ei_L_ld_t(dec,:,end))+sum(tmp.ei_t(dec,:,end))...
                    +sum(tmp.er_t(dec,:,end))+sum(tmp.er_L_ld_t(dec,:,end)) + ... 
                    + tmp.ui_t(dec,end) + tmp.ur_t(dec,end) + tmp.oi_t(dec,end) + tmp.or_t(dec,end) + ...
                    + sum(tmp.deaths(:,end)) + ...
                    +sum(tmp.ei2_L_ld_t(dec,:,end)) + sum(tmp.ei2_t(dec,:,end)) ...
                    +sum(tmp.er2_L_ld_t(dec,:,end)) + sum(tmp.er2_t(dec,:,end)) ...
                        + sum( 1 - exp(-tmp.oi_t(:,end)*param.chi*aux.dt) );

          end
        end
        [a,b,c] = size(tmp.ei_L_ld_t);

        if pp==1
            emp_dec_lf(i,:) = emp_dec;
            infect_dec_lf(i,:) = infect_dec;
        elseif pp==2
            emp_dec_lck3(i,:) = emp_dec;
            infect_dec_lck3(i,:) = infect_dec;
        elseif pp==3
            emp_dec_lck6(i,:) = emp_dec;
            infect_dec_lck6(i,:) = infect_dec;
        end

    end
    
end


% Set deciles 
deciles =[10;20;30;40;50;60;70;80;90];

% %infection risk for no furlough
figure(1)
subplot(131)
plot(deciles,infect_dec_lf(1,:),'k-','linewidth',2)
hold on
yyaxis right
plot(deciles,infect_dec_lck3(1,:),'r-',...
    deciles,infect_dec_lck6(1,:),'b-',...
    'linewidth',2)
xlabel('Wages, deciles')
legend('Laissez faire (left axis)', '3 Month Lockdown (right axis)','6 Month Lockdown (right axis)', 'location','South')
ax = gca;
ax.YAxis(1).Color = 'k';
ax.YAxis(2).Color = 'k';


% %employment risk for no furlough
figure(1)
subplot(132)
plot(deciles,emp_dec_lf(1,:),'k-',...
    deciles,emp_dec_lck3(1,:),'r-',...
    deciles,emp_dec_lck6(1,:),'b-',...
    'linewidth',2)
xlabel('Wages, deciles')
legend('Laissez faire', '3 Month Lockdown','6 Month Lockdown', 'location','SouthEast')


% %employment risk for furlough
figure(2)
subplot(131)
plot(deciles,infect_dec_lck6(1,:),'b-',...
    deciles,infect_dec_lck6(2,:),'b-.',...
    'linewidth',2)
xlabel('Wages, deciles')
legend('6 Month Lockdown','6 Month Lockdown + Furlough', 'location','SouthEast')

% %employment risk for furlough
figure(2)
subplot(132)
plot(deciles,emp_dec_lck6(1,:),'b-',...
    deciles,emp_dec_lck6(2,:),'b-.',...
    'linewidth',2)
xlabel('Wages, deciles')
legend('6 Month Lockdown','6 Month Lockdown + Furlough', 'location','SouthEast')

%% Wage risk
clear

% Load model solution
load('final_model.mat')

% Load model solution with furlough
load('final_model_furlough.mat')

% Auxiliaries
aux = struct( ...
    'steady_state', 1,...   % whether or not initiating model at ss with li=0
    'x_grid', 50,...        % size of productivity grid
    'trim', 1e-2, ...       % trimming of distributions
    'x_lb', 0.5, ...        % lower bound of productiviry distribution 
    'alpha_grid', 50,...
    'inf_grid', 120 ,...
    'us_grid', 5, ...
    'ur_grid', 5, ...
    'max_li', 0.25, ...
    'max_us', 0.4, ...
    'max_ur', 0.2,...   
    'display', 0, ...
    'calibrate',0, ...
    'T',365*5, ...          % number of dts simulated for
    'dt',1/7, ...
    'l_ini', 1/66/10^6, ... % initial 'viral load'
    'conv_diff',1e-2, ...   % relative difference required for convergence tolerance
    'update',0.1, ...       % weight of new variable when updating
    'lockdown',0, ...       % whether the model is solved in lockdown
    'death_ini', 1, ...     % start time series when UK hits this number of Covid deaths
    't_period', 24, ...     % number of dts to implement lockdown
    'furlough',0 ...        % indicator if furlough is in place
    );

for pol = 1:2
    
    if pol==1
        policy=lf;
    elseif pol==2
        policy=lck_6;
    end

    [~,mm] = max(policy.deaths); %point where deaths peak

    plot_grid=[];

    for xx=1:aux.x_grid
        x_tmp = zeros(aux.x_grid*aux.alpha_grid,1);
        x_tmp(1 +(xx-1)*aux.x_grid:xx*aux.x_grid) = ones(aux.x_grid,1);
        %check positive mass at point
        check = (sum(policy.es0_L_ld_t(x_tmp==1,mm)) + sum(policy.es1_L_ld_t(x_tmp==1,mm)) ...
            + sum(policy.es0_t(x_tmp==1,mm)) + sum(policy.es1_t(x_tmp==1,mm)) + ...
            sum(policy.ei_L_ld_t(x_tmp==1,mm)) + sum(policy.ei_t(x_tmp==1,mm)) + sum(policy.er_L_ld_t(x_tmp==1,mm)) + sum(policy.er_t(x_tmp==1,mm))   );
        
        if check>0
            w1 = policy.ws1(x_tmp==1,1);
            mw =( sum( (policy.ws0_L_ld(x_tmp==1,mm).*policy.es0_L_ld_t(x_tmp==1,mm) + policy.ws1_L_ld(x_tmp==1,mm).*policy.es1_L_ld_t(x_tmp==1,mm) + policy.ws0(x_tmp==1,mm).*policy.es0_t(x_tmp==1,mm) + policy.ws1(x_tmp==1,mm).*policy.es1_t(x_tmp==1,mm) + ...
                policy.wi_L_ld(x_tmp==1,mm).*policy.ei_L_ld_t(x_tmp==1,mm)  + policy.ei_t(x_tmp==1,mm).*policy.wi(x_tmp==1,mm) + policy.er_L_ld_t(x_tmp==1,mm).*policy.wr_L_ld(x_tmp==1,mm) + policy.er_t(x_tmp==1,mm).*policy.wr(x_tmp==1,mm)))  ...
                ) /...
                (sum(policy.es0_L_ld_t(x_tmp==1,mm)) + sum(policy.es1_L_ld_t(x_tmp==1,mm)) + sum(policy.es0_t(x_tmp==1,mm)) + sum(policy.es1_t(x_tmp==1,mm)) + ...
                sum(policy.ei_L_ld_t(x_tmp==1,mm)) + sum(policy.ei_t(x_tmp==1,mm)) + sum(policy.er_L_ld_t(x_tmp==1,mm)) + sum(policy.er_t(x_tmp==1,mm))   );

            plot_grid = [plot_grid; [w1(1),mw]];
        end

    end
    
    if pol==1
        plot_grid_1 = plot_grid;
    elseif pol==2
        plot_grid_2 = plot_grid;
    end

end

policy=lck_f_6;

[~,mm] = max(policy.deaths);

plot_grid_3=[];
for xx=1:aux.x_grid
        x_tmp = zeros(aux.x_grid*aux.alpha_grid,1);
        x_tmp(1 +(xx-1)*aux.x_grid:xx*aux.x_grid) = ones(aux.x_grid,1);
        %check positive mass at point
        check = sum(policy.es0_L_ld_t(x_tmp==1,mm)) + sum(policy.es1_L_ld_t(x_tmp==1,mm)) ...
            + sum(policy.es0_t(x_tmp==1,mm)) + sum(policy.es1_t(x_tmp==1,mm)) + ...
            sum(policy.ei_L_ld_t(x_tmp==1,mm)) + sum(policy.ei_t(x_tmp==1,mm)) + sum(policy.er_L_ld_t(x_tmp==1,mm)) ...
            + sum(policy.er_t(x_tmp==1,mm))  + sum(policy.es2_L_ld_t(x_tmp==1,mm)) + sum(policy.es2_t(x_tmp==1,mm))  ...
            +sum(policy.ei2_L_ld_t(x_tmp==1,mm)) + sum(policy.ei2_t(x_tmp==1,mm)) +  sum(policy.er2_L_ld_t(x_tmp==1,mm)) ...
            + sum(policy.er2_t(x_tmp==1,mm)) ;

        if check>0
            w1 = policy.ws1(x_tmp==1,1);
            mw = sum((policy.ws0_L_ld(x_tmp==1,mm).*policy.es0_L_ld_t(x_tmp==1,mm) + ...
                policy.ws1_L_ld(x_tmp==1,mm).*policy.es1_L_ld_t(x_tmp==1,mm) + ...
                policy.ws2_L_ld(x_tmp==1,mm).*policy.es2_L_ld_t(x_tmp==1,mm) +...
                policy.ws0(x_tmp==1,mm).*policy.es0_t(x_tmp==1,mm) + ...
                policy.ws1(x_tmp==1,mm).*policy.es1_t(x_tmp==1,mm) + ...                       
                policy.ws2(x_tmp==1,mm).*policy.es2_t(x_tmp==1,mm) +...
                policy.wi_L_ld(x_tmp==1,mm).*policy.ei_L_ld_t(x_tmp==1,mm) + ...
                policy.wi2_L_ld(x_tmp==1,mm).*policy.ei2_L_ld_t(x_tmp==1,mm) + ...
                policy.wi(x_tmp==1,mm).*policy.ei_t(x_tmp==1,mm) + ...                       
                policy.wi2(x_tmp==1,mm).*policy.ei2_t(x_tmp==1,mm) + ...
                policy.wr_L_ld(x_tmp==1,mm).*policy.er_L_ld_t(x_tmp==1,mm) + ...
                policy.wr2_L_ld(x_tmp==1,mm).*policy.er2_L_ld_t(x_tmp==1,mm) + ...
                policy.wr2(x_tmp==1,mm).*policy.er2_t(x_tmp==1,mm)) + ...
                policy.wr(x_tmp==1,mm).*policy.er_t(x_tmp==1,mm)  ...
                )/...
                sum(     policy.es0_L_ld_t(x_tmp==1,mm) + policy.es1_L_ld_t(x_tmp==1,mm) + policy.es0_t(x_tmp==1,mm) + policy.es1_t(x_tmp==1,mm) + ...
                policy.ei_L_ld_t(x_tmp==1,mm)  + policy.ei_t(x_tmp==1,mm) + policy.er_L_ld_t(x_tmp==1,mm)  + policy.er_t(x_tmp==1,mm) + ...
                policy.es2_L_ld_t(x_tmp==1,mm) + policy.es2_t(x_tmp==1,mm) + policy.ei2_L_ld_t(x_tmp==1,mm) + policy.ei2_t(x_tmp==1,mm) + ...
                policy.er2_L_ld_t(x_tmp==1,mm) + policy.er2_t(x_tmp==1,mm));
                     
            plot_grid_3 = [plot_grid_3; [w1(1),mw]];
        end
end

wage_dis_ini_tmp = [lf.es1_t((lf.es1_t(:,1)>0),1)./sum(lf.es1_t(:,1)),lf.ws1((lf.es1_t(:,1)>0),1)];
wage_dis_ini= [];
for tt=1:length(wage_dis_ini_tmp)/aux.alpha_grid
    wage_dis_ini = [wage_dis_ini; ...
        [sum(wage_dis_ini_tmp(1+(tt-1)*aux.x_grid:tt*aux.x_grid,1)), wage_dis_ini_tmp(tt*aux.x_grid,2)] ];
    if tt>1
        wage_dis_ini(tt,1) = wage_dis_ini(tt,1)+wage_dis_ini(tt-1,1);
    end
end
deciles = interp1(wage_dis_ini(:,1),wage_dis_ini(:,2),[0:.1:.9]','pchip','extrap');
clear wage_dis_ini_tmp wage_dis_ini

%add lower bound
lf_wage = [interp1(plot_grid_1(:,1),plot_grid_1(:,2),deciles(1),'pchip','extrap');...
    plot_grid_1(:,2)];
lock_wage = [interp1(plot_grid_2(:,1),plot_grid_2(:,2),deciles(1),'pchip','extrap');...
    plot_grid_2(:,2)];
furl_wage = [interp1(plot_grid_3(:,1),plot_grid_3(:,2),deciles(1),'pchip','extrap');...
    plot_grid_3(:,2)];

figure(1)
subplot(133)
min_w=350; max_w=750;
hh = plot([deciles(1);plot_grid_1(:,1)],lf_wage,'k-' ,...
    [deciles(1);plot_grid_1(:,1)],lock_wage,'b-','linewidth',3);
hold on
plot([deciles(1);plot_grid_3(:,1)],[deciles(1);plot_grid_3(:,1)],'k--','linewidth',3)
for tt=2:9
    plot([deciles(tt),deciles(tt)],[min_w,max_w],'k--')
end
legend(hh,'Laissez-faire','6 month lockdown','location','northwest')
xlabel('Pre-pandemic wage')
axis([deciles(1),700,350,700])
saveas(gcf,'BRS_Figure_4.png')

figure(2)
subplot(133)
min_w=350; max_w=750;
hh = plot(...[deciles(1);plot_grid_1(:,1)],lf_wage,'k-' ,...
    [deciles(1);plot_grid_1(:,1)],lock_wage,'b-',...
    [deciles(1);plot_grid_1(:,1)],furl_wage,'b--','linewidth',3);
hold on
plot([deciles(1);plot_grid_3(:,1)],[deciles(1);plot_grid_3(:,1)],'k--','linewidth',3)
for tt=2:9
    plot([deciles(tt),deciles(tt)],[min_w,max_w],'k--')
end
legend(hh,'6 month lockdown','6 month lockdown + furlough','location','northwest')
axis([deciles(1),700,350,700])
xlabel('Pre-pandemic wage')
saveas(gcf,'BRS_Figure_7.png')

